@@ -21,6 +21,7 @@ export * from './medications.js';
 export * from './notes.js';
 export * from './patientFields.js';
 export * from './patientDetails.js';
+export * from './permissions.js';
 export * from './referenceData.js';
 export * from './reports.js';
 export * from './servers.js';
@@ -35,7 +36,6 @@ export * from './programRegistry.js';
 export * from './vaccines.js';
 export * from './settings.js';
 export * from './encounterHistory.js';
-export * from './font.js';
 export * from './webSocket.js';
 export * from './enumRegistry.js';
 export * from './materializedView.js';
